import React, { useState, useEffect } from 'react'
import request, { apis } from '@/utils/request'
import { useModel } from '@/store'
import Taro from '@tarojs/taro'
import WuYeBaoXiuItem from '@/components/WuYeBaoXiuItem/index'
import ScrollPage from '@/components/ScrollPage/index'
import '@/assets/css/reset.less'
import '@/assets/css/iconfont.less'
import './index.less'

export default function WuYeBaoXiu (props) {

  const { user } = useModel('user')
  const [IsPullUp, setIsPullUp] = useState(false)
  const [IsPullDown, setIsPullDown] = useState(false)
  const [HasNextPage, setHasNextPage] = useState(true)
  const [PageNum, setPageNum] = useState(1)
  const [PageList, setPageList] = useState([])

  useEffect(() => {
    GetPageList(() => {
      setIsPullUp(false)
    })
  }, [PageNum])

  const GetPageList = (done = () => { }) => { // 获取列表
    request({ ...apis.getGongDanList, args: { orgId: user.orgId }, params: { pageNum: PageNum, pageSize: 10, type: 2 } }).then((res) => {
      if (PageNum === 1) {
        setPageList([...res.records])
      } else {
        setPageList(PageList.concat([...res.records]))
      }
      setHasNextPage(res.current - 0 < res.pages - 0)
      done()
    }).catch(() => {
      done()
    })
  }

  const OnRefresh = () => { // 页面下拉刷新
    setIsPullDown(true)
    setHasNextPage(true)
    setPageNum(1)
    if (PageNum === 1) {
      GetPageList(() => {
        setIsPullDown(false)
      })
    } else {
      setPageNum(1)
    }
  }

  const OnPullUp = () => {
    if (HasNextPage) {
      setIsPullUp(true)
      setPageNum(PageNum + 1)
    }
  }

  return (
    <view className='WuYeBaoXiu'>
      <ScrollPage IsPullDown={IsPullDown} IsPullUp={IsPullUp} HasMore={HasNextPage} OnRefresh={OnRefresh} OnPullUp={OnPullUp}>

        {/* 大图 */}
        <view className='BigImg'>
          <image mode='aspectFill' src={null} className='centerLabel'></image>
        </view>

        {/* 我要报修 */}
        <view className='WoYaoBaoXiu'>
          <view onClick={() => { Taro.navigateTo({ url: `/pages/WuYe/BaoXiuQuYu/index` }) }}>
            <text className='iconfont iconjia'></text>
            <text>我要报修</text>
          </view>
        </view>

        {/* 报修列表 */}
        <view className='List'>
          {
            PageList.map((item, index) => (
              <view key={`WuYeBaoXiuItem-${index}`}>
                <WuYeBaoXiuItem Data={{ ...item, id: index }}></WuYeBaoXiuItem>
              </view>
            ))
          }
        </view>

      </ScrollPage>
    </view>
  )
}
