import React, { useState, useEffect } from 'react'
import request, { apis } from '@/utils/request'
import { useModel } from '@/store'
import WuYeFuWuItem from '@/components/WuYeFuWuItem/index'
import ScrollPage from '@/components/ScrollPage/index'
import '@/assets/css/reset.less'
import '@/assets/css/iconfont.less'
import './index.less'

export default function WuYeFuWu () {

  const { user } = useModel('user')
  const [IsPullUp, setIsPullUp] = useState(false)
  const [IsPullDown, setIsPullDown] = useState(false)
  const [HasNextPage, setHasNextPage] = useState(true)
  const [PageNum, setPageNum] = useState(1)
  const [PageList, setPageList] = useState([])

  useEffect(() => {
    GetPageList(() => {
      setIsPullUp(false)
    })
  }, [PageNum])

  const GetPageList = (done = () => { }) => { // 获取列表
    request({ ...apis.getGongGaoList, args: { orgId: user.orgId }, params: { pageNum: PageNum, pageSize: 10 } }).then((res) => {
      if (PageNum === 1) {
        setPageList([...res.records])
      } else {
        setPageList(PageList.concat([...res.records]))
      }
      setHasNextPage(res.current - 0 < res.pages - 0)
      done()
    }).catch(() => {
      done()
    })
  }

  const OnRefresh = () => { // 页面下拉刷新
    setIsPullDown(true)
    setHasNextPage(true)
    setPageNum(1)
    if (PageNum === 1) {
      GetPageList(() => {
        setIsPullDown(false)
      })
    } else {
      setPageNum(1)
    }
  }

  const OnPullUp = () => {
    if (HasNextPage) {
      setIsPullUp(true)
      setPageNum(PageNum + 1)
    }
  }

  return (
    <view className='WuYeFuWu'>
      <ScrollPage IsPullDown={IsPullDown} IsPullUp={IsPullUp} HasMore={HasNextPage} OnRefresh={OnRefresh} OnPullUp={OnPullUp}>
        {/* 大图 */}
        <view className='BigImg'>
          <image mode='aspectFill' src={null} className='centerLabel'></image>
        </view>

        {/* 物业办事指南 */}
        <view className='BanShiZhiNan'>
          <text>物业办事指南</text>
          <view className='flex-h'>
            <view className='Line'><view></view></view>
            <view className='flex-item'>
              <text>1、业主收楼手续办理</text>
              <text>2、物业转名手续办理</text>
              <text>3、业主卡、住户卡办理</text>
            </view>
          </view>
        </view>

        {/* 服务列表 */}
        <view className='List'>
          {
            PageList.map((item, index) => (
              <view key={`WuYeFuWuItem-${index}`}>
                <WuYeFuWuItem Data={item}></WuYeFuWuItem>
              </view>
            ))
          }
        </view>
      </ScrollPage>
    </view>
  )
}
