import React, { useState, useEffect } from 'react'
import request, { apis } from '@/utils/request'
import { useModel } from '@/store'
import WuYeJiaoFeiItem from '@/components/WuYeJiaoFeiItem/index'
import ScrollPage from '@/components/ScrollPage/index'
import '@/assets/css/reset.less'
import '@/assets/css/iconfont.less'
import './index.less'

export default function WuYeJiaoFei () {

  const { user } = useModel('user')
  const [IsPullUp, setIsPullUp] = useState(false)
  const [IsPullDown, setIsPullDown] = useState(false)
  const [HasNextPage, setHasNextPage] = useState(true)
  const [PageNum, setPageNum] = useState(1)
  const [PageList, setPageList] = useState([])

  useEffect(() => {
    GetPageList(() => {
      setIsPullUp(false)
    })
  }, [PageNum])

  const GetPageList = (done = () => { }) => { // 获取列表
    request({ ...apis.getJiaoFeiList, args: { type: 0 }, params: { pageNum: PageNum, pageSize: 10 } }).then((res) => {
      if (PageNum === 1) {
        setPageList([...res.records])
      } else {
        setPageList(PageList.concat([...res.records]))
      }
      setHasNextPage(res.current - 0 < res.pages - 0)
      done()
    }).catch(() => {
      done()
    })
  }

  const OnRefresh = () => { // 页面下拉刷新
    setIsPullDown(true)
    setHasNextPage(true)
    setPageNum(1)
    if (PageNum === 1) {
      GetPageList(() => {
        setIsPullDown(false)
      })
    } else {
      setPageNum(1)
    }
  }

  const OnPullUp = () => {
    if (HasNextPage) {
      setIsPullUp(true)
      setPageNum(PageNum + 1)
    }
  }

  return (
    <view className='WuYeJiaoFei'>
      <ScrollPage IsPullDown={IsPullDown} IsPullUp={IsPullUp} HasMore={HasNextPage} OnRefresh={OnRefresh} OnPullUp={OnPullUp}>

        {/* 大图 */}
        <view className='BigImg'>
          <image mode='aspectFill' src={null} className='centerLabel'></image>
        </view>

        {/* 缴费列表 */}
        <view className='List'>
          {
            PageList.map((item, index) => (
              <view key={`WuYeJiaoFeiItem-${index}`}>
                <WuYeJiaoFeiItem Data={item}></WuYeJiaoFeiItem>
              </view>
            ))
          }
        </view>

      </ScrollPage>
    </view>
  )
}
