import React, { useState, useEffect } from 'react'
import TabPageCutNav from '@/components/TabPageCutNav/index'
import NavHeader from '@/components/NavHeader/index'
import ActivityListItem from '@/components/ActivityListItem/index'
import NewsListItem from '@/components/NewsListItem/index'
import ScrollPage from '@/components/ScrollPage/index'
import request, { apis } from '@/utils/request'
import '@/assets/css/reset.less'
import '@/assets/css/iconfont.less'
import './index.less'

export default function HuoDong (props) {

  const [NavList] = useState([{ name: '活动', id: 1 }, { name: '资讯', id: 2 }])
  const [CurrentNavId, setCurrentNavId] = useState(1)
  const [IsPullDown, setIsPullDown] = useState(false)
  const [IsPullUp, setIsPullUp] = useState(false)
  const [HasNextPage, setHasNextPage] = useState(true)
  const [PageNum, setPageNum] = useState(1)
  const [ActivityList, setActivityList] = useState([])
  const [ActivityTotal, setActivityTotal] = useState(1)
  const [NewsList, setNewsList] = useState([])

  useEffect(() => {
    if (CurrentNavId === 1) { // 活动
      GetActivityList(() => {
        setIsPullUp(false)
      })
    } else if (CurrentNavId === 2) { // 资讯
      GetNewsList(() => {
        setIsPullUp(false)
      })
    }
  }, [PageNum])

  useEffect(() => {
    setHasNextPage(ActivityTotal > ActivityList.length)
  }, [ActivityList])

  useEffect(() => {
    OnRefresh()
  }, [CurrentNavId])

  const GetActivityList = (done = () => { }) => { // 获取活动列表
    request({ ...apis.getActivityList, params: { pageNum: PageNum, pageSize: 6 } }).then((res) => {
      setActivityTotal(res.total)
      if (PageNum === 1) {
        setActivityList([...res.list])
      } else {
        setActivityList(NewsList.concat([...res.list]))
      }
      done()
    }).catch(() => {
      done()
    })
  }

  const GetNewsList = (done = () => { }) => { // 获取资讯列表
    request({ ...apis.getNewsList, params: { pageNum: PageNum, pageSize: 6 } }).then((res) => {
      if (PageNum === 1) {
        setNewsList([...res.records])
      } else {
        setNewsList(NewsList.concat([...res.records]))
      }
      setHasNextPage(res.current - 0 < res.pages - 0)
      done()
    }).catch(() => {
      done()
    })
  }

  const NavChange = (e) => { // nav切换
    return () => {
      setCurrentNavId(e.id)
      setHasNextPage(true)
      setIsPullDown(false)
      setIsPullUp(false)
      setPageNum(1)
    }
  }

  const OnRefresh = () => { // 下拉刷新
    setIsPullDown(true)
    setHasNextPage(true)
    if (PageNum === 1) {
      if (CurrentNavId === 1) {
        GetActivityList(() => {
          setIsPullDown(false)
        })
      } else if (CurrentNavId === 2) {
        GetNewsList(() => {
          setIsPullDown(false)
        })
      }
    } else {
      setPageNum(1)
    }
  }

  const OnPullUp = () => { // 上拉加载
    if (HasNextPage) {
      setIsPullUp(true)
      setPageNum(PageNum + 1)
    }
  }

  return (
    <view className='HuoDong flex-v'>
      <NavHeader BgColor='none' Title='活动' IsFixed={true}></NavHeader>
      <TabPageCutNav List={NavList} CurrentNavId={CurrentNavId} NavChange={NavChange}></TabPageCutNav>
      <view className='flex-item'>
        <view>
          <ScrollPage OnRefresh={OnRefresh} IsPullDown={IsPullDown} OnPullUp={OnPullUp} IsPullUp={IsPullUp} HasMore={HasNextPage}>
            {/* 活动 */}
            {
              CurrentNavId - 0 === 1 &&
              <view className='Content Activity'>
                {
                  ActivityList.map((item, index) => (
                    <view className='ListItem' key={`ActivityItem-${index}`}>
                      <ActivityListItem Data={item}></ActivityListItem>
                    </view>
                  ))
                }
              </view>
            }

            {/* 资讯 */}
            {
              CurrentNavId - 0 === 2 &&
              <view className='Content News'>
                <view className='BigImg'>
                  <image mode='aspectFill' src={null} class='centerLabel'></image>
                </view>
                <view className='List'>
                  {
                    NewsList.map((item, index) => (
                      <view className='ListItem' key={`NewsItem-${index}`}>
                        <NewsListItem Data={item} ShowTips={index === 0}></NewsListItem>
                      </view>
                    ))
                  }
                </view>
              </view>
            }
          </ScrollPage>
        </view>
      </view>
    </view>
  )
}
